/*
 * This is copyrighted software.  Originally uploaded at the GIMP Plugin
 * Registry (http://registry.gimp.org/).  This is to be distributed
 * ("conveyed") under the terms of version 3 of the GNU General Public License
 * (no other version, see the file "COPYING" for details).  THERE IS NO IMPLIED
 * WARRANTY FOR THIS PROGRAM.  USE AT YOUR OWN RISK.  For inquiries, email the
 * author at stamit@stamit.gr .  You may not remove this notice.
 */
#ifndef __RENDER_H__
#define __RENDER_H__

#include "main.h"

#include <libgimp/gimpui.h>


typedef struct InterpolateInvocation {
	GimpDrawable *drawable;
	PlugInVals *vals;
} InterpolateInvocation;

void invoke_render(InterpolateInvocation *inv, GimpPreview *preview);
void render(GimpDrawable *drawable, PlugInVals *vals, GimpPreview *preview);

#endif /* __RENDER_H__ */
